~~Das **Simple Network Management Protocol** (**SNMP**) ist ein Netzwerkprotokoll zur **Überwachung und Steuerung von Netzwerkgeräten** wie Router, Switches, Firewalls, Drucker oder NAS Appliances. SNMP wurde schrittweise ausgebaut und unterstützt in der Version SNMP v3 neben einer **Authentifizierung** auch eine **Verschlüsselung** der übertragenen Daten. [[@noauthor_snmp_nodate]]

### Verwendete Ports

~~Die Verbindung erfolgt verbindungslos per UDP Ports 161 und 162.(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-3)

- ~~UDP 161 zur Abfrage der Agenten
- ~~UDP 162 für Traps, automatische Meldungen, werden bei unnormalem Verhalten von Agenten an Manager gesendet.(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-4) [[@noauthor_snmp_nodate]]

### Agent

~~Die Agenten-Komponente von SNMP läuft üblicherweise auf dem überwachten Serversystem, Appliance oder Netzwerkgerät. Sie können Systemzustände erfassen, Einstellungen vornehmen und auch Aktionen auslösen. Einer dieser Agenten ist der snmpd, ein Daemon der auf Linux-basierten Betriebssystemen die Agentenkomponente abbildet(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-5) [[@noauthor_snmp_nodate]]

### Manager

~~Auf den Client-Servern oder auch auf Monitoring-Servern wird nun die zweite der beiden Komponenten eingesetzt. Sie dient zur Abfrage der Daten, oder aber auch um Aktionen ausführen zu können. Meist ist jedoch nur eine eingeschränkte Konfiguration der Agenten auf vielen Appliances vorhanden, es können meist nur Daten abgefragt werden. Bei Linux-basierten Betriebssystemen bilden die Applikationen des NET-SNMP Paketes diese Manager-Rolle aus. Es kann bequem per apt installiert werden, siehe Abschnitt [SNMP einsetzen].

| Datenpaket                          | Beschreibung                                                                                            | Beispieltool                                                                                                                                                                       |
| ----------------------------------- | ------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| GET-REQUEST                         | Wird zum Anfordern eines spezifischen Datensatzes verwendet, eine eindeutige OID muss angegeben werden. | snmpget(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-6)                                                                                                     |
| GETNEXT-REQUEST                     | Durchläuft auch die nachfolgenden Datensätze, z.B. Tabellen                                             | snmpgetnext(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-7)                                                                                                 |
| GETBULK                             | Angegebene Anzahl an Datensätze auf einmal abrufen, ähnlich zu mehreren GETNEXT-REQUESTS                | snmpwalk(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-8)                                                                                                    |
| SET-REQUEST                         | Verändern von einem oder mehreren Datensätzen                                                           | snmpset(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-9)                                                                                                     |
| GET-RESPONSE                        | Empfängt die Antwort auf eines der vorab gesendeten Pakete                                              | snmpstatus(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-10)                                                                                                |
| TRAP                                | Unaufgeforderte Nachricht, bei Auftritt eines Ereignisses, vom Agenten an einen Manager                 | snmptrapd(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-11), dieser Daemon läuft auf dem Manager-System, z.B. Monitoringserver und lauscht am Port 162 UDP. |
| [[@thomas_niedermeier_snmp_nodate]] |                                                                                                         |                                                                                                                                                                                    |

## SNMP Versionen

~~Die nachfolgende Tabelle vergleicht die Parameter der drei aktuell gebräuchlichen SNMP Versionen, die zur Abfrage von SNMP-Daten mit snmpget und snmpwal(https://www.thomas-krenn.com/de/wiki/Abfrage_von_SNMP-Daten_mit_snmpget_und_snmpwalk "Abfrage von SNMP-Daten mit snmpget und snmpwalk") erforderlich sind. Im Monitoringbereich wird vor allem ein Nagios-Plugin "check_snmp" eingesetzt, zum Beispiel basieren unsere eigenen TKmon Servicechecks für Synology NAS(https://www.thomas-krenn.com/de/wiki/TKmon_Servicechecks_f%C3%BCr_Synology_NAS "TKmon Servicechecks für Synology NAS") auf diesem Plugin. Bei diesem Plugin unterscheiden sich die Parameter teilweise, z.B. ist hier der Parameter -o vor der Angabe der OID erforderlich. [[@thomas_niedermeier_snmp_nodate]]

|                   |     SNMP v1      | SNMP v2c |      SNMP v3       |
| ----------------- |:----------------:|:--------:|:------------------:|
| Authentifizierung | Community-String |          | Username, Passwort |
| Verschlüsselung   |        -         |          |   Pre-Shared-Key   |

[[@thomas_niedermeier_snmp_nodate]]

### SNMP v2

~~SNMP v2 exisiterte in verschiedenen Ausprägungen, die heute noch existente Version ist **v2c**, die Erweiterung **c** bedeutet community-based SNMP. Sie ist sicherheitstechnisch auf dem Stand von SNMP v1 und wurde um zusätzliche Funktionen aus der nicht mehr verwendeten v2p, party-based SNMP, erweitert. Tabellen werden somit nicht wie bei v2 per GetNext sondern per GetBulk abgefragt. Sie ermöglicht eine Kommunikation zwischen einzelnen Managern. Die Version v2c hat sich im Gegensatz zu den bereits eingestellten Ausprägungen v2p und v2u (user-based SNMP) durchgesetzt und erfährt die breiteste Unterstützung im Markt. [[@thomas_niedermeier_snmp_nodate]]

### SNMP v3

~~Sicherheitsfunktionen waren bis einschließlich SNMP v2 nicht ausreichend vorhanden, deshalb wurde SNMP v3 spezifiziert. Es erhöht durch Sicherheitsmerkmale wie Usernamen und Passwort, sowie einer Übertragungsverschlüsselung der Daten die Sicherheit enorm. Die Komplexität erhöht sich im gleichen Maße natürlich ebenso, es stehen im Vergleich zu v2c deutlich mehr Konfigurationsmöglichkeiten zur Verfügung. Es wird das User Based Security Module (USM) angewandt, als derzeit einziges von SNMP v3 unterstütztes.[(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-12) Das USM ist in der RFC 2574 definiert. [[@thomas_niedermeier_snmp_nodate]]

~~**Wichtiger Hinweis:** Wenn das zu überwachende Netzwerkgerät v3 unterstützt, sollte v3 auf jeden Fall v2 vorgezogen werden. Ebenso sollte es mit der größtmöglichen Sicherheitsstufe erfolgen, z.B. es sollte nicht auf eine Übertragungsverschlüsselung verzichtet werden, wenn dies unterstützt wird. Geräte von Synology z.B unterstützen derzeit nur die Methode _--AuthNoPriv_. Dies bedeutet, dass eine verschlüsselte Passwort-Authentifizierung erfolgt, die Übertragung der Daten aber im Klartext.(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-14) (https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-15) [[@thomas_niedermeier_snmp_nodate]]

~~Die nachfolgende Tabelle zeigt die Konfigurationsmöglichkeiten von SNMP v3 und die dafür erforderlichen Parameter zur Abfrage mit snmpwalk auf. [[@thomas_niedermeier_snmp_nodate]]

| Authentifizierungs- und Verschlüsselungsarten | Beschreibung                                                                                                             |
| --------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------ | 
| noAuthNoPriv                                  | Keine Authentifizierung, keine Übertragungsverschlüsselung der Daten, Angabe des Usernamen                               |
| authNoPriv                                    | Authentifizierung, keine Übertragungsverschlüsselung der Daten, Abfrage des Usernamen und Passwortes                     |
| authPriv                                      | Authentifizierung und Übertragungsverschlüsselung der Daten, Abfrage Username, Passwort und Passwort der Verschlüsselung |

[[@thomas_niedermeier_snmp_nodate]]

~~Die OIDs, Object Identifer, sind weltweit eindeutige Bezeichner für Objekte.(https://www.thomas-krenn.com/de/wiki/SNMP_Grundlagen#cite_note-16) Ein OID stellt einen Knoten in einem hierarchischen Namensraum dar. Jeder Knoten ist eindeutig durch eine Folge von Nummern gekennzeichnet. Damit lässt sich die Position des Knotens im Baum feststellen. Umso länger die Kette, umso spezifischer die Information, viele Knoten des OID-Baumes enthalten keine Informationen, sondern nur Verweise auf die darunterliegenden. Die OIDs bestehen aus ganzen Zahlen und werden z.B. per Punkt-Notation miteinander verkettet. Weitere Darstellungsarten sind die ASN.1 Notation, wie auch in den MIBs verwendet, und die URN-Notation.

### Beispiel-OIDs

Nachfolgende Beispiele verdeutlichen den Aufbau einer OID.

- Top Node
    - Wurzel des OID-Baumes
    - OID assignments from the top node(http://www.alvestrand.no/objectid/top.html)
- Internet OID
    - 1.3.6.1
    - OID assignments from 1.3.6.1 - Internet(http://www.alvestrand.no/objectid/1.3.6.1.html)
- Internet Private Enterprises OIDs
    - 1.3.6.1.4.1
    - 1.3.6.1.4.1 - IANA-registered Private Enterprises(http://www.alvestrand.no/objectid/1.3.6.1.4.1.html)
    - Jede Firma hat einen eindeutigen Knoten unterhalb des Internet Private Enterprise Knotens
    - Synology hat z.B. die Nummer **6574**, dies ergibt zusammengesetzt: **1.3.6.1.4.1.6574**
[[@thomas_niedermeier_snmp_nodate]]

~~Neben den OID-Ketten sind die MIBs, Management Information Base, eine weitere zentrale Komponente eines Netzwerk-Management-Protokolls wie SNMP. Die Objekte werden Managed Objects genannt und werden in der Spezifikationssprache ASN.1 verfasst. Die MIBs enthalten keine Daten, sie liefern jedoch Erklärungen, wo welche Informationen zu finden sind und wie sie aussehen, z.B. welche Rückgabewerte es für die spezifische OID gibt, oder welcher Datentyp verwendet wird. [[@thomas_niedermeier_snmp_nodate]]


![[Snmp-agent-manager.png]]  [[@thomas_niedermeier_snmp_nodate]]

---

~~SNMP ist ein Protokoll zur Verwaltung und Steuerung von Netzwerken.
Es ist für den Transport von Management-Informationen, Status- und Statistikdaten zwischen Netzwerkstationen und einem Management-System zuständig.[[@noauthor_snmp_nodate-1]]

~~Bei der Einführung von TCP/IP wurde kurzfristig SNMP verwendet und sollte durch ein OSI-konformes Protokoll ersetzt werden.
SNMP setzte sich jedoch innerhalb kürzester Zeit durch. Die Anpassung an die Anforderungen von OSI waren jedoch zu umfangreich.
Deshalb wurden das neue Protokoll ausgesetzt.
Stattdessen wurde kurzerhand SNMP, SMI und MIB zu den offiziellen Standards erklärt.
Deshalb muss in allen verwaltbaren Netzwerk-Komponenten SNMP, SMI und MIB implementiert sein. [[@noauthor_snmp_nodate-1]]

~~Mit zunehmender Tendenz werden immer mehr Anwendungen aus der Informations- und Kommunikationstechnik in betriebliche Arbeitsabläufe integriert.
Dadurch entstehen immer größere und komplexere Netzwerke, an die immer mehr Anwendungen und Benutzer angeschlossen werden.
Um Probleme und Störungen in einem Netzwerk frühzeitig erkennen und beseitigen zu können sind Elemente erforderlich, die ein Netzwerk verwalten und beobachten können.
An dieser Stelle setzen Netzwerk-Management-Systeme an.
Diese Systeme werden allgemein unter der Bezeichnung Netzwerk-Management-Technologie (NMT) zusammengefasst.  [[@noauthor_snmp_nodate-1]]

~~Die Architektur von SNMP trennt zwischen dem Manager, den Agenten, den Verwaltungsinformationen und dem Verwaltungsprotokoll.
Der Manager ist eine Anwendung auf einem speziell dafür vorgesehenen Computer.
Die Agenten sind die einzelnen Netzwerk-Komponenten. Sie führen die Management-Funktionen aus.
Die Verwaltungsinformationen sind Informationen über das Netzwerk, der Konfiguration, dem Aufbau und den statistischen Daten.
Das Verwaltungsprotokoll ist SNMP selber.
Es tauscht die Verwaltungsinformationen und Daten zwischen dem Manager und den Agenten aus.  
Der Ablauf zwischen Manager und Agenten ist immer der selbe.
Der Manager schickt einen Request an den Agenten.
Dieser führt den Befehl aus und schickt einen Response zurück.
Dieses Verfahren wird Polling genannt.
Weiterhin existieren Traps, die einen Agenten dazu veranlassen, unvorhergesehene Ereignisse an den Manager zu melden.
Viele gleichzeitig versendete Traps können jedoch zur Überlastung des Managers führen.
Deshalb sind Traps nur bei kritischen Ereignissen empfehlenswert.
Um eine unnötige Netzwerkbelastung zu vermeiden, findet der Datenaustausch von SNMP über UDP statt. [[@noauthor_snmp_nodate-1]]

~~Die mit SNMP übertragenen Informationen und Daten müssen irgendwo abgelegt und gespeichert werden.
Dazu dient die MIB.
Die MIB ist mit einer Datenbank vergleichbar.
In ihr werden hauptsächlich Daten gespeichert.
Die Daten werden in Form von Objekten strukturiert in einer Art Baum abgelegt.
Wegen den Bedürfnissen des Netzwerk-Managements wurde die Standard-MIB durch Erweiterungen angepasst.
Daraus ergab sich die MIB II.  
Wegen der steigenden Komplexität wurde SNMP und MIB durch die RMON-MIB (Remote Monitoring) erweitert. [[@noauthor_snmp_nodate-1]]

---

~~Das Grundkonzept von SNMP sieht den Informationsaustausch zwischen Agenten und einem zentralen Manager über Netzwerkpakete vor. Solche Informationen können Statistik- oder Statusdaten aber auch Steuerungs- und Konfigurationsdaten sein.
Das Simple Network Management Protocol beschreibt den Aufbau der Datenpakete und den genauen Ablauf der Kommunikation.
Es existieren verschiedene SNMP-Versionen; aktuelle Versionen unterstützen Sicherheitsmechanismen wie Verschlüsselung. [[@donner_was_2018]]

~~Bei SNMP kommunizieren die Agenten der einzelnen Endgeräte mit einem oder mehreren zentralen Managern.
Bei den Agenten handelt es sich in der Regel um Software, die direkt auf den zu überwachenden Komponenten läuft.
Die Software kann den Status und die Konfiguration einer Komponente erfassen, Aktionen ausführen oder Einstellungen vornehmen. [[@donner_was_2018]]

~~Der Manager ist eine Software auf einem dafür vorgesehenen Rechner, die mit den Agenten kommuniziert und deren Meldungen entgegennimmt.
Das Kommunikationsprotokoll ist SNMP.
Der typische Ablauf einer Kommunikation sieht vor, dass der Manager einen Request an den Agenten schickt, den dieser ausführt und mit einem Response-Paket beantwortet.
Darüber hinaus kann der Agent unaufgeforderte Informationen über so genannte Traps versenden.
Sie kommen oft bei unvorhergesehenen oder kritischen Ereignissen zum Einsatz. [[@donner_was_2018]]

~~Eine zentrale Rolle bei der Überwachung und Steuerung der Netzwerkelemente durch SNMP nimmt die Management Information Base (MIB) ein, über die die Bereitstellung von Informationen der Objekte läuft.
Es handelt sich bei der MIB um eine Art Datenbank, in der die Daten in einer baumartigen Objektstruktur abgelegt sind.
Die MIB repräsentiert die Datenbasis, die in einem Netzwerkelement vorhanden ist und per Simple Network Management Protocol abgefragt werden kann.
Neben der Standard-MIB existieren zahlreiche Erweiterungen und herstellerspezifische Objekte. [[@donner_was_2018]]

---

~~SNMP-Softwareagenten auf Netzwerkgeräten und -diensten kommunizieren mit dem Netzwerkmanagementsystem, um Statusinformationen und Konfigurationsänderungen weiterzugeben.
Das NMS bietet eine einzige Schnittstelle, über die Administratoren Batch-Befehle erteilen und automatische Warnmeldungen erhalten können. [[@jessica_scarpati_was_nodate]]

~~SNMP basiert auf dem Konzept einer Managementinformationsbasis, um zu organisieren, wie Informationen über Gerätemetriken ausgetauscht werden.
Die MIB ist eine formale Beschreibung der Komponenten und Statusinformationen eines Netzwerkgeräts.
MIBs können für jedes Netzwerkgerät, etwa im Internet der Dinge ([IoT](https://www.computerweekly.com/de/definition/Internet-der-Dinge-Internet-of-Things-IoT)) erstellt werden.
Beispiel sind [IP](https://www.computerweekly.com/de/definition/Internet-Protocol-IP)-Videokameras, Fahrzeuge, Industrieanlagen und medizinische Geräte.
Neben der Hardware kann SNMP auch zur Überwachung von Diensten wie dem Dynamic Host Configuration Protocol ([DHCP](https://www.computerweekly.com/de/definition/DHCP-Dynamic-Host-Configuration-Protocol)) eingesetzt werden. [[@jessica_scarpati_was_nodate]]

~~SNMP verwendet eine Mischung aus Pull- und Push-Kommunikation zwischen Netzwerkgeräten und dem Netzwerkmanagementsystem.
Der SNMP-Agent, der sich mit der MIB auf einem Netzwerkgerät befindet, sammelt ständig Statusinformationen.
Er sendet aber nur auf Anfrage oder wenn ein Aspekt des Netzwerks einen vordefinierten Schwellenwert überschreitet, der als Trap bekannt ist, Informationen an das Netzwerküberwachungssystem.
Trap-Meldungen werden typischerweise an den Managementserver gesendet, wenn etwas Wichtiges auftritt, wie zum Beispiel ein schwerer Fehlerzustand. [[@jessica_scarpati_was_nodate]]

~~SNMP enthält auch einen _Inform_-Nachrichtentyp, der es einem Netzwerk-Monitoring-Tool ermöglicht, Nachrichten von einem Gerät zu bestätigen.
Inform-Meldungen ermöglichen es dem Agenten, einen ausgelösten Alarm zurückzusetzen.
Netzwerkmanagement-Tools können auch eine _Set_-Nachricht verwenden, um über den SNMP-Agenten Änderungen an einem Netzwerkgerät vorzunehmen.
Diese Fähigkeit ermöglicht es dem Netzwerkmanager, als Reaktion auf neue Netzwerkereignisse Änderungen an den Gerätekonfigurationen durchzuführen. [[@jessica_scarpati_was_nodate]]

~~In den meisten Fällen funktioniert SNMP in einem synchronen Modell, wobei die Kommunikation vom SNMP-Manager initiiert wird und der Agent eine Antwort sendet.
Typischerweise verwendet SNMP [UDP](https://www.computerweekly.com/de/definition/UDP-User-Datagram-Protocol) als Transportprotokoll. Die bekannten UDP-[Ports](https://www.computerweekly.com/de/definition/Port) für den SNMP-Verkehr sind 161 (SNMP) und 162 (SNMPTRAP).
Diese beiden Ports sind grundlegende Standardeinstellungen und in allen Versionen von SNMP gleich. [[@jessica_scarpati_was_nodate]]

~~SNMP wird als _simpel_ bezeichnet, weil die Architektur des Protokolls so unkompliziert ist.
SNMP kann Lese- oder Schreibbefehle ausgeben, wie zum Beispiel das Zurücksetzen eines Passworts oder das Ändern einer Konfigurationseinstellung.
Es kann auch zurückmelden, wie viel [Bandbreite](https://www.computerweekly.com/de/definition/Bandbreite), [CPU](https://www.computerweekly.com/de/definition/CPU) und Speicher in Gebrauch sind. Als eines der am weitesten verbreiteten Protokolle wird SNMP von einer breiten Palette an Hardware unterstützt – von konventionellen Netzwerkgeräten wie Routern, [Switches](https://www.computerweekly.com/de/definition/Switch) und [WLAN](https://www.computerweekly.com/de/definition/WLAN-Wireless-LAN-oder-Wireless-Local-Area-Network) [Access Points](https://www.computerweekly.com/de/definition/Access-Point-AP) bis hin zu Endpunkten wie [Druckern](https://www.computerweekly.com/de/definition/Drucker), Scannern und IoT-Geräten. [[@jessica_scarpati_was_nodate]]

**~~SNMP-Agent:** Diese Software läuft auf der zu überwachenden Hardware oder dem zu überwachenden Dienst und sammelt Daten über Festplattenspeicher, Bandbreitennutzung und andere wichtige Metriken zur Netzwerkleistung.
Bei einer Abfrage durch den SNMP-Manager sendet der Agent die angeforderten Informationen zurück an das Managementsystem.
Ein Agent kann das NMS auch proaktiv benachrichtigen, wenn ein Fehler auftritt.
Auf den meisten Geräten ist ein SNMP-Agent vorinstalliert, er muss jedoch in der Regel eingeschaltet und konfiguriert werden. [[@jessica_scarpati_was_nodate]]

~~**SNMP-verwaltete Netzwerkknoten:** Dies sind die Netzwerkgeräte und -dienste, auf denen die Agenten laufen. [[@jessica_scarpati_was_nodate]]

~~**SNMP-Manager:** Das Netzwerkmanagementsystem ist eine Softwareplattform, die als zentrale Konsole fungiert, an die die Agenten Informationen liefern.
Das NMS fordert die Agenten aktiv auf, in regelmäßigen Abständen Updates zu senden.
Was ein Netzwerkmanager mit diesen Informationen machen kann, hängt stark davon ab, wie funktionsreich das NMS ist.
Es gibt mehrere kostenlose SNMP-Manager, die jedoch in der Regel in ihren Fähigkeiten oder der Anzahl der unterstützten Knoten begrenzt sind.
Am anderen Ende des Spektrums bieten Enterprise-Grade-Plattformen erweiterte Funktionen für komplexere Netzwerke, wobei einige Produkte bis zu Zehntausende von Netzwerkknoten unterstützen. [[@jessica_scarpati_was_nodate]]

~~**Managementinformationsbasis (MIB):** Diese Datenbank ist eine Textdatei (.mib), die alle Objekte auf einem bestimmten Gerät auflistet und beschreibt, die über SNMP abgefragt oder gesteuert werden können.
Jedem MIB-Element wird ein Objektidentifikator (OID) zugewiesen. [[@jessica_scarpati_was_nodate]]

---

~~SNMP steht für Simple Network Management Protocol und ist ein weit verbreitetes Protokoll zum Monitoring von Netzwerkgeräten.
Es lässt sich jedoch nicht nur als Monitoring-Protokoll verwenden, sondern, wie der Name schon sagt, auch für die Verwaltung und Konfiguration.
Mit SNMP erkennen Sie Fehler rechtzeitig und werden in Echtzeit über Netzwerkprobleme informiert. [[@noauthor_was_nodate-4]]

~~SNMP wurde Mitte der 1980er Jahre entwickelt und hat sich in den 1990er Jahren und Anfang der 2000er Jahre allmählich zu einem Standard für [Netzwerk-Monitoring](https://checkmk.com/de/guides/netzwerk-monitoring) entwickelt.
Dank der großen Bandbreite an Metriken, die es erfassen kann, und seiner relativen Simplizität ist es heute noch für die Überwachung weit verbreitet.
Es ist allerdings nicht fehlerfrei.
Um diese zu beheben, wurden über die Jahre drei Versionen des Protokolls entwickelt, wenn auch nicht ganz erfolgreich. [[@noauthor_was_nodate-4]]

~~SNMP arbeitet mit zwei Hauptkomponenten: einem SNMP-Agenten und einem SNMP-Manager.
Der Agent besteht aus einer kleinen Applikation, auf dem zu überwachenden Gerät installiert wird, dort lokal Metriken sammelt und diese an einen remoten Standort sendet.
Der SNMP-Manager befindet sich auf der Empfängerseite.
Damit der Manager die Informationen vom Agenten abrufen kann, verwendet er eine Reihe von Befehlen.
Zudem kann der Agent bei Bedarf eigenständig Informationen in Form von SNMP-Traps senden, was eine der bekanntesten Funktionen des SNMP-Protokolls ist.
Im Wesentlichen sammelt ein SNMP-Protokoll Metriken und ermöglicht einen strukturierten Austausch dieser Metriken zwischen einem Agenten und einem Manager. [[@noauthor_was_nodate-4]]

~~Der Agent und der Manager kommunizieren über eine der Versionen von SNMP.
Je nach gewählter Version müssen Sie unterschiedliche Einstellungen vornehmen.
Die Konfiguration von SNMP ist jedoch dank seines Alters nicht besonders komplex.
SNMP ist also ein Protokoll, dass mithilfe eines Agenten und eines Managers Netzwerkgeräte überwacht und wartet.
Das sind allerdings nicht alle seine Funktionen, wie wir gleich sehen werden. [[@noauthor_was_nodate-4]]

~~Der SNMP-Agent ist die Software-Komponente, die Abfragen beantwortet, Anfragen ausführt und Traps versendet.
Im Wesentlichen haben SNMP-Agenten drei Aufgaben.
Zum einen beantworten sie eine SNMP Get-Anfrage des Managers, die Informationen über das verwaltete Gerät abfragt.
Die zweite Aufgabe ist ähnlich.
Dabei sendet ein SNMP-Manager eine Abfrage zur Verwaltung oder Konfiguration des verwalteten Geräts an einen SNMP-Agenten, der diese Abfrage wiederum an seinen Host weiterleitet. [[@noauthor_was_nodate-4]]

~~Die letzte, aber nicht weniger wichtige Aufgabe ist das Trap-Signal, das der Agent an den Manager senden kann, um ihn über einen soeben aufgetretenen Fehler zu informieren.
Ein SNMP-Agent ist also nicht nur eine passive Applikation, die nur auf den Manager reagiert, sondern kann bei Bedarf oder nach entsprechender Konfiguration auch aktiv Informationen senden.
Man kann einen SNMP-Agenten auch als den Kern des SNMP-Protokolls bezeichen, der Metriken sammelt und Fehler an den SNMP-Manager zurückmeldet. [[@noauthor_was_nodate-4]]

~~Der SNMP-Manager befindet sich im Gegensatz zum Agenten am anderen Ende eines SNMP-Setups.
In der Regel installiert man SNMP-Manager auf einer NMS (Network Management Station), von der es je nach Anzahl der verwalteten Geräte durchaus mehrere pro Netz geben kann. [[@noauthor_was_nodate-4]]

~~Ein SNMP-Manager ist für das Monitoring und die entsprechenden Verarbeitungsaufgaben zuständig.
Die benötigten Hardware-Ressourcen sind daher höher als bei einem Agenten.
Obwohl Sie SNMP zwar direkt von der Befehlszeile aus verwenden können, ist es heutzutage üblicher, eine Monitoring-Software mit Dashboards und automatischen Abfragen als SNMP-Manager zu implementieren.
Während ein SNMP-Agent ein kleines Programm mit relativ starren Funktionen ist, kann ein SNMP-Manager eine komplexe Software sein, die SNMP-Abfragen zwar unterstützt, aber nicht auf diese beschränkt ist. [[@noauthor_was_nodate-4]]

~~Ein SNMP-Gerät ist das Gerät, auf dem ein SNMP-Agent installiert ist.
Dazu gehören Switches, Bridges, Router, Access-Server, Hubs, Drucker und allgemeine Hosts.
Das ist nur ein Teil der möglichen Geräte, denn SNMP ist allgegenwärtig und kann fast überall installiert werden.
Der SNMP-Agent hingegen wird oft von den Herstellern auf den Netzwerkgeräten vorinstalliert. [[@noauthor_was_nodate-4]]

~~Dementsprechend kann jedes Gerät nach einer einfachen Installation des Agenten ein SNMP-Gerät werden.
SNMP wird weitgehend unterstützt und ist für alle wichtigen Betriebssysteme verfügbar, auch für ungewöhnlichere wie Android oder iOS. [[@noauthor_was_nodate-4]]

~~SNMP wurde in den frühen 1980er Jahren von einer Gruppe entwickelt, die die damaligen Bemühungen als nicht umsetzbar und nicht praktikabel ansahen.
Es hat also eine lange Geschichte, die sich bereits über drei Jahrzehnte erstreckt.
Im Laufe der Jahre wurden mehrere Versionen des Protokolls veröffentlicht.
Die ursprüngliche Version v1 ist heute weitestgehend aus allen modernen Infrastrukturen verschwunden, ausgenommen ein bestimmtes Gerät konnte nicht auf die zweite Version von SNMP, v2, aufgerüstet werden. [[@noauthor_was_nodate-4]]

~~Das Hauptproblem an v1 war seine Sicherheit.
Diese war in allen praktischen Aspekten von v1 überhaupt nicht vorhanden, sondern wurde den Kanälen überlassen, über die die SNMP-Nachrichten gesendet wurden. [[@noauthor_was_nodate-4]]

~~SNMP v2, und insbesondere seine etwas sicherere Variante v2c, ist bis heute bei weitem am weitesten verbreitet.
SNMP v2 wurde 1993 veröffentlicht und mit neuen Befehlen und einem parteibasierten Sicherheitssystem ergänzt, das sich jedoch nicht durchsetzen konnte.
Stattdessen setzte sich SNMP v2c durch, mit dem man ein einfacheres Community-basiertes Sicherheitssystem und ein 64-Bit-Zähler eingeführt hat (das ursprüngliche SNMP hatte nur 32-Bit). [[@noauthor_was_nodate-4]]

~~Parallel zu SNMP v2c wurde v2u als Kompromiss entwickelt, das zwar eine bessere Sicherheit als v1 bot, aber weniger komplex als v2 war. Obwohl es keine weite Verbreitung fand, war es eine wichtige Inspiration für v3. [[@noauthor_was_nodate-4]]

~~SNMP v2 und alle seine Varianten sind nicht mit v1 kompatibel, da die Nachrichten einen anderen Header und andere Protokolldatenformate verwenden. [[@noauthor_was_nodate-4]]

~~In den frühen 2000er Jahren erschien dann v3, mit Unterstützung für Kryptografie und vielen verschiedenen Konzepten, Konventionen und Terminologien.
Am Kernprotokoll hat sich jedoch nicht viel geändert, und viele Hersteller zogen es vor, bei den besser getesteten und weniger rechenintensiven Versionen 2 und 2c zu bleiben. [[@noauthor_was_nodate-4]]

~~SNMP wird hauptsächlich für das IT-Monitoring eingesetzt.
Mit SNMP ist es möglich, die wichtigen Parameter Ihrer Switches, Access Points und Router sowie die vielen anderen Gerätetypen, auf denen SNMP häufig installiert ist, im Auge zu behalten.
Dazu gehören Appliances, Hardware-Sensoren und Drucker, was SNMP zu einer Komplettlösung für das Hardware-Monitoring macht. [[@noauthor_was_nodate-4]]

~~Die Fähigkeiten des SNMP-Protokolls gehen sogar über die reine Überwachung hinaus.
Schließlich steht SNMP für Simple Network Management Protocol, und ist dementsprechend  auch für die Verwaltung einsetzbar.
Die Remote-Verwaltung und -Konfiguration von Geräten ist eines der Haupteinsatzgebiete von SNMP.
Mit einem einfachen SNMP-Client oder Monitoring-Tool können Sie Parameter und Optionen bei vielen Geräten per SNMP aus der Ferne ändern. [[@noauthor_was_nodate-4]]

~~Um das SNMP-Monitoring einzurichten, ist normalerweise nur ein geringer Aufwand notwendig.
Da auf vielen Geräten bereits ein SNMP-Agent installiert ist, müssen Sie diesen nur noch aktivieren, um mit der Überwachung des Geräts zu beginnen.
Um den Agenten zu aktivieren, müssen Sie diesen so konfigurieren, dass er aktive Anfragen, meist SNMP Get- und Set-Befehle, annimmt.
In der Regel ist es aber am besten, zuerst im Handbuch des jeweiligen Geräts nachzuschlagen, da die Hersteller unterschiedliche Implementierungen des Protokolls haben. [[@noauthor_was_nodate-4]]

~~Sobald die Agenten aktiviert sind, kann Ihre Monitoring-Lösung nun Informationen und Metriken über das Gerät per SNMP abrufen.
Häufig wird dies durch einen vollständigen Abruf aller SNMP-Daten auf den verwalteten Geräten erreicht, einem SNMP Walk.
Wie und was abgerufen wird, hängt vom Ihnen oder der gewählten Monitoring-Software ab
Checkmk beispielsweise nutzt die Service-Erkennung über SNMP, indem es nur die allerersten Datensätze (OIDs) auf einem Gerät abruft.
Auf der Grundlage dieser Informationen werden bei Bedarf weitere Abfragen durchgeführt, ohne erstmal große Datenmengen übertragen zu müssen.
Dadurch geht das Erkennen von SNMP-Geräten deutlich schneller und effizienter, was bei großen Infrastrukturen ansonsten schnell viele Stunden dauern kann. [[@noauthor_was_nodate-4]]

~~Sobald alle Informationen gefunden und die Agenten aktiv sind, kann das eigentliche Monitoring starten.
Die verwalteten Geräte sind bereit, Anfragen zu bestimmten Metriken vom Manager zu bearbeiten.
Diese werden von den Agenten gesammelt und dann über das Netzwerk an den Manager gesendet, der sie anschließend analysiert. Gelegentlich kann ein Agent einen Trap an den Manager zurücksenden, aber meistens ist der Manager in der aktiven Position. [[@noauthor_was_nodate-4]]

~~OID (Object Identifier) ist ein Identifizierungsmechanismus, der jede Art von Objekt oder Konzept benennt.
Dabei handelt es sich um einen internationalen Standard für die Adressierung von Objekten auf eine ganz bestimmte Art und Weise. 
SNMP hat das Konzept übernommen, aber nicht erfunden. [[@noauthor_was_nodate-4]]

~~Eine SNMP-OID ist eine lange Folge von Zahlen, die durch Punkte getrennt sind.
Zum Beispiel ist 1.3.6.1.2.2.1.5 eine OID, die ein Objekt in einem hierarchischen logischen Baum eindeutig identifiziert.
OIDs sollten von links nach rechts gelesen werden, beginnend mit der Root, die, je nach [Arc](https://de.wikipedia.org/wiki/Gerichteter_Graph) der folgenden Normen, entweder 0, 1 oder 2 ist:

- ~~0 steht für [ITU-T](https://de.wikipedia.org/wiki/Comit%C3%A9_Consultatif_International_T%C3%A9l%C3%A9graphique_et_T%C3%A9l%C3%A9phonique) (einer der drei Sektoren der International Telecommunication Union). [[@noauthor_was_nodate-4]]
- ~~1 steht für die [ISO](https://de.wikipedia.org/wiki/Internationale_Organisation_f%C3%BCr_Normung) (Internationale Organisation für Normung). [[@noauthor_was_nodate-4]]
- ~~2 steht für einen gemeinsamen ISO/ITU-T-Arc. [[@noauthor_was_nodate-4]]

Die Organisationen definieren jeweils die untergeordneten Nodes und können die Zuweisungsbefugnis an andere delegieren. [[@noauthor_was_nodate-4]]

~~Im obigen Beispiel steht die 1 für ISO, die 3 für die „identifizierte Organisation“ und die 6 für das amerikanische Verteidigungsministerium.
Dies zieht sich bis zur allerletzten Ziffer im Baum, die je nach Kontext eine bestimmte „Sache“ bezeichnet.
Dabei handelt es sich häufig um eine Variable, die eine für das überwachte Gerät spezifische Metrik angibt.
Das kann beispielsweise die Temperatur eines Prozessors oder die Betriebszeit eines Hosts sein. [[@noauthor_was_nodate-4]]

~~Einige Zweige sind allgemeiner Natur, andere gehören zu bestimmten Organisationen oder Unternehmen und spezifizieren deren Produkt.
Sie werden von SNMP überwacht und machen die OID damit zu einem wichtigen Bestandteil, um zu wissen, was und wo jedes Gerät ist, das SNMP unterstützt.
Jedem Hersteller steht es frei, seine eigenen Zweige zu spezifizieren, abhängig von seinen Geräten und deren Funktionen. [[@noauthor_was_nodate-4]]

~~Diese langen Zahlenreihen wären von geringem Nutzen, wenn es nicht möglich wäre, die Bedeutung jeder Zahl abzurufen.
Zu diesem Zweck wird ein weiterer Teil der SNMP-Funktionalität verwendet, die MIB (Management Information Base). [[@noauthor_was_nodate-4]]

~~[[grafik-OID-tree.jpeg]] [[@noauthor_was_nodate-4]]

~~Eine MIB in SNMP übersetzt OIDs in eine für Menschen lesbare Form, indem sie Namen, Definitionen und Beschreibungen für die jeweiligen Werte bereitstellt.
Da jeder Anbieter eine andere Klassifizierung für seine eigenen OID-Zweige hat, wird eine MIB in Form einer Tabelle dargestellt, die zur Gruppierung von Instanzen eines tabellarischen Objekts verwendet wird. [[@noauthor_was_nodate-4]]

~~Jede MIB hat Zeilen, die eine Reihe von Informationen oder Einstellungen für ein Objekt darstellen.
Dies kann beispielsweise der Name, der Typ und die aktuelle Temperatur eines Hardware-Sensors sein oder auch die Anzahl der Hardware-Ports, die maximale und aktuelle Geschwindigkeit jedes Ports und die Firmware-Version eines Switches.
Je komplexer das Gerät ist, desto mehr Ziffern werden verwendet, um alle seine Funktionen, Metriken und Einstellungen zu indizieren. [[@noauthor_was_nodate-4]]

~~Jeder Hersteller pflegt und aktualisiert seine MIBs.
Dabei handelt es sich um von Menschen lesbare Wörterbücher, die mit den OIDs des jeweiligen Geräts übereinstimmen.
Um zu funktionieren, benötigt das Protokoll nur die OIDs.
Die MIBs informieren die Netzwerk-Admins darüber, was bei jeder OID zu finden ist. [[@noauthor_was_nodate-4]]

~~SNMP Get ist der einfachste Vorgang beim SNMP-Monitoring.
Der SNMP-Manager verwendet den Get-Befehl, um Informationen vom Agenten abzurufen.
Dabei gibt er die OID an, von der die Informationen abgerufen werden sollen.
Bei jedem SNMP Get-Befehl wird eine OID bezogen, wobei bei jedem Durchlauf immer nur eine einzelne Metrik abgerufen wird. [[@noauthor_was_nodate-4]]

~~Basierend auf der verwendeten SNMP-Version ist in der Regel auch ein Community-String erforderlich, um sich dem Agenten gegenüber zu authentifizieren.
Außerdem ist die Adresse der Zielgeräte notwendig.
Der Agent sorgt dafür, dass die richtigen Daten unter der gewünschten OID abgerufen werden. [[@noauthor_was_nodate-4]]

~~Was passiert, wenn Sie eine große Anzahl von Metriken über SNMP abrufen wollen, ohne dabei jede einzeln angeben zu müssen?
Genau dafür ist die Applikation SNMP Walk zuständig.
Sie verwendet den SNMP-Befehl GetNext, um einen ganzen Zweig ab einer bestimmten OID abwärts abzurufen.
Alle Variablen in diesem Zweig unterhalb der angegebenen OID werden abgefragt und an den SNMP-Manager zurückgegeben. [[@noauthor_was_nodate-4]]

~~Wenn SNMP Walk keine OID, sondern nur die Adresse eines Geräts angibt, fragt er alle zu diesem Gerät gehörenden Variablen ab.
Durch die großen Datenmengen, die dabei übermittelt werden, kann sich der Prozess jedoch stark verlangsamen. [[@noauthor_was_nodate-4]]

~~Beim SNMP-Monitoring ist dies eine der nützlichsten Methoden, um die Gesundheit eines Geräts oder eines Teils Ihres Netzwerks zu überprüfen.
SNMP Walk ist eine einfache und leicht zu automatisierende Methode, um einen guten Überblick über ein oder mehrere verwaltete Geräte zu erhalten. [[@noauthor_was_nodate-4]]

~~SNMP-Agenten kommunizieren mithilfe von SNMP-Traps mit dem Manager, ohne dass dieser zuvor eine Abfrage sendet.
Dementsprechend kann ein Agent einen Manager mit SNMP-Traps sofort über wichtige Ereignisse informieren. [[@noauthor_was_nodate-4]]

~~Der Agent kann sowohl allgemeine als auch herstellerspezifische Arten von Traps senden.
Die allgemeinen Traps dienen dazu, übliche Ereignisse zu melden, beispielsweise dass eine Verbindung unterbrochen oder wiederhergestellt wurde, dass das Gerät neu initialisiert wurde oder dass die Authentifizierung fehlgeschlagen ist.
Herstellerspezifische Traps können mehrere verschiedene Traps speziell für Enterprise-Umgebungen umfassen. [[@noauthor_was_nodate-4]]

~~Der Manager reagiert auf jede Art von Trap mit den Maßnahmen, die der implementierten Netzwerk-Monitoring-Software entsprechen.
Da SNMP-Traps einem Echtzeit-Benachrichtigungssystem innerhalb des Protokolls am nächsten kommen, sind sie für das Alerting beim Netzwerk-Monitoring von großem Nutzen. [[@noauthor_was_nodate-4]]

~~SNMP-Community-Strings funktionieren wie Passwörter zur Authentifizierung zwischen SNMP-Agenten und -Managern.
Ein Community-String ist eine alphanumerische Zeichenfolge, die früher standardmäßig "public" lautete.
Heutzutage ist das allerdings nicht mehr üblich.
Bei SNMP v1 und v2c wird die Zeichenfolge als Plain Text über das Netzwerk gesendet.
Stimmt sie überein, erhält der Manager Zugriff auf den Agenten. [[@noauthor_was_nodate-4]]

~~Um Spoofing zu verhindern, hat man mit SNMP v3 die Verschlüsselung von Community-Strings eingeführt.
Die Verschlüsselung muss allerdings vorkonfiguriert werden.
Außerdem kann sie das Monitoring verlangsamen, da sie besonders den Agenten, aber auch den Manager stärker belastet.
Vor dem Umstieg auf v3 sollte man daher abwägen, ob die Leistungsfähigkeit der zugrundeliegenden Hardware ausreicht. [[@noauthor_was_nodate-4]]

~~Unabhängig von der verwendeten SNMP-Protokollversion wird dringend empfohlen, den Standard-Community-String zu ändern, da er Angreifern wohlbekannt ist.
Generell ist SNMP nicht sehr sicher und wenn der Netzwerkbereich nicht gerade von der Außenwelt abgeschottet ist, bietet die Verwendung eines benutzerdefinierten Community-Strings und die Aktivierung der Verschlüsselung nur eine halbwegs sichere Umgebung für das Monitoring. [[@noauthor_was_nodate-4]]

---


SNMP has evolved into three versions: SNMPv1, SNMPv2c, and SNMPv3. All SNMP messages are transported via User Datagram Protocol (UDP), and each version supports GET, GetNext, and Set SNMP operations. [[@noction_snmp_2022]]

### SNMPv1

The original version of SNMP, referred to as SNMPv1, has critical security and performance limitations. [[@noction_snmp_2022]]

SNMPv1 provides authentication, which is based on a password (community string). The community string is sent in clear text between the NMS manager and the agents. Therefore, the managed device is vulnerable to unauthorized users who can easily reconfigure the device, especially if IP access control lists (ACLs) are not in place. [[@noction_snmp_2022]]

The SNMPv1 and 2c data exchanged between the NMS administrator and the agents are not encrypted. For example, the community string in the Get Response depicted in Figure 2 is “public.” [[@noction_snmp_2022]]

Regarding SNMPv1 protocol performance, the set of protocol transactions is limited to Gets, Sets, and Traps of individual objects in the MIB. Therefore, large sets of information require several transactions to retrieve a row of information. [[@noction_snmp_2022]]

### SNMPv2c

SNMPv2c is the successor to the original SNMPv1. The standard MIB2 integer is 32 bits long in the case of SNMPv1; SNMPv2 defines a new type of integer that is 64 bits long. A 64-bit counter can better handle high-speed interfaces because 32-bit counters do not provide enough capacity and must wrap quickly. This increases network traffic and has a negative impact on both the agent and the NMS manager CPU utilization. [[@noction_snmp_2022]]

SNMPv2c also improves the performance of SNMPv1 by introducing the Get Bulk Requests operation. If the NMS manager wants to retrieve a large amount of data, it sends a GetBulk message to the agent instead of a Get request. The GetBulk operation provides values for all variables in the list and is much more efficient than sending repetitive GetNext commands. [[@noction_snmp_2022]]

SNMpv2c introduces a new type of SNMP communication – SNMP Inform request. Typically, an SNMP Inform is used for manager-to-manager communication to acknowledge receipt of notification. The SNMP inform request packet will be sent continually until the sending SNMP manager receives an SNMP acknowledgment. [[@noction_snmp_2022]]

Both SNMPv2c and SNMPv1 protocols use simple authentication, which relies on community names. [[@noction_snmp_2022]]

### SNMPv3

SNMPv3 is the latest SNMP protocol that addresses the security issues introduced by older SNMP versions. SNMpv3 provides message integrity, authentication, and encryption by implementing SNMP View, SNMP Group, and SNMP User. [[@noction_snmp_2022]]

SNMP View defines what a particular SNMpv3 user can view. For example, it is possible to configure that a user will only have access to view the interface index, OID 1.3.6.1.2.1.2, and anything below that.  [[@noction_snmp_2022]]
To create an all-access View the name iso should be specified. The MIB has a tree structure so anything below the iso can be accessed (Figure 2). [[@noction_snmp_2022]]

SNMP Group is associated with the SNMP View and it defines a type of the access – read-only or read/write. It also defines the type of security that is active when interacting with the device.

   noauth – nor authentication or encryption
   auth – only authentication, no encryption
   priv – authentication and encryption

SNMP User is added to the group with the level of authentication and encryption. The security model must match the group, e.g. priv, a type of the hash for the password (e.g. SHA), the password, encryption algorithm (e.g. AES), and a shared secret for generating encryption keys. [[@noction_snmp_2022]]

---

## Stichpunkte

SNMP -> Protokoll zur Steuerung und Überwachung von Netzwerkgeräten wie Router/Switche [[@noauthor_snmp_nodate]]

Verwendete Ports:
- 161/UDP: zur Abfrage von Agenten
- 162/UDP: für SNMP Traps [[@noauthor_snmp_nodate]]

Agent:
Läuft auf zu überwachenden Systemen. Kann Systemzustände erfassen, Einstellungen ändern und Aktionen auslösen. [[@noauthor_snmp_nodate]]

|                   |     SNMP v1      | SNMP v2c |      SNMP v3       | 
| ----------------- |:----------------:|:--------:|:------------------:| 
| Authentifizierung | Community-String |          | Username, Passwort | 
| Verschlüsselung   |        -         |          |   Pre-Shared-Key   | 

[[@thomas_niedermeier_snmp_nodate]]

OID:
Object Identifier
weltweit eindeutige Bezeichner für Objekte
Stellt knoten in einem hirerachischen Namensbaum dar.
Jeder Knoten ist eindeutig durch Nummernfolge gekennzeichnet -> Position im Baum feststellbar 
längere Kette -> Spezifischere Informationen
Verkettung per Punktnotation [[@thomas_niedermeier_snmp_nodate]]

Beispiel OID

- Top Node
    - Wurzel des OID-Baumes
    - [OID assignments from the top node](http://www.alvestrand.no/objectid/top.html)
- Internet OID
    - 1.3.6.1
    - [OID assignments from 1.3.6.1 - Internet](http://www.alvestrand.no/objectid/1.3.6.1.html)
- Internet Private Enterprises OIDs
    - 1.3.6.1.4.1
    - [1.3.6.1.4.1 - IANA-registered Private Enterprises](http://www.alvestrand.no/objectid/1.3.6.1.4.1.html)
    - Jede Firma hat einen eindeutigen Knoten unterhalb des Internet Private Enterprise Knotens
    - Synology hat z.B. die Nummer **6574**, dies ergibt zusammengesetzt: **1.3.6.1.4.1.6574**
[[@thomas_niedermeier_snmp_nodate]]

MIB:
Management Information Base
Enthalten keine Daten, sondern wo welche Informationen zu finden sind und wie diese aussehen z.B. Rückgabewerte o. Datentyp [[@thomas_niedermeier_snmp_nodate]]

---

SNMP -> Protokoll zur Verwaltung und Steuerung von Netzwerken
Zuständig für Management-Informationen, Status- und Statistikdaten zwischen Netzwerkstationen und einem Management-System.[[@noauthor_snmp_nodate-1]]

Bei Einführung von TCP/IP sollte SNMP nur als Übergangslösung verwendet werden -> Ersetzung durch OSI-konformes Protokoll [[@noauthor_snmp_nodate-1]]

SNMP hat sich aber durchgesetzt; Anpassungen an OSI waren zu umfangreich -> Neues Protokoll ausgesetzt worden [[@noauthor_snmp_nodate-1]]

SNMP, SMI und MIB wurden offizielle Standards  [[@noauthor_snmp_nodate-1]]

Zunehmende Tendenz: Integration von Anwendungen aus Informations-/Kommunikationstechnik in betriebliche Abläufe [[@noauthor_snmp_nodate-1]]

Immer komplexere Netze mit mehr Anwendungen und Benutzern -> Elemente notwendig, die Netze verwalten und beobachten können -> Dafür Netzwerk-Management-Systeme notwendig [[@noauthor_snmp_nodate-1]]

Komponenten:
	- Manager
	- Agent
	- Verwaltungsinformationen
	- Verwaltungsprotokoll [[@noauthor_snmp_nodate-1]]

Manager: Anwendung auf speziellem Server[[@noauthor_snmp_nodate-1]]

Agents: einzelne Netzwerkkomponenten, führen Management-Funktionen aus[[@noauthor_snmp_nodate-1]]

Verwaltungsinformationen: Informationen über Netzwerk, Konfiguration, Aufbau und statistische Daten[[@noauthor_snmp_nodate-1]]

Verwaltungsprotokoll: SNMP -> Tauscht Verwaltungsinformationen und Daten zwischen Master und Agenten aus[[@noauthor_snmp_nodate-1]]

Ablauf zwischen Master und Agent ist immer gleich:
	- Manager sendet Request an Agent
	- Agent führt Befehl aus und antwortet mit Response
	- -> Polling [[@noauthor_snmp_nodate-1]]

Traps: unvorhergesehene Ereignisse werden an Manager gesendet -> Zu viele Traps überlasten den Master -> Deshalb Traps nur bei kritischen Ereignissen [[@noauthor_snmp_nodate-1]]

UDP, um Netzwerkbelastung zu verringern [[@noauthor_snmp_nodate-1]]

MIB -> vergleichbar mit Datenbank
Speichert zu übertragende Informationen und Daten
Daten werden in Objekten strukturiert und in einer Baumstruktur abgelegt
MIB-Standard wurde wegen neuer Bedürfnisse weiterentwickelt
Zusätzliche Erweiterung von SNMP und MIB durch RMON-MIB (Remote Monitoring) [[@noauthor_snmp_nodate-1]]

---

Grundkonzept sieht Informationsaustausch zwischen Agenten und Manager über Netzwerkpakete vor [[@donner_was_2018]]

Informationen -> Statistik oder Statusdaten bzw. Steuer/Konfigurationsdaten [[@donner_was_2018]]

SNMP (Simple Network Management Protocol) beschreibt Aufbau der Datenpakete und Ablauf der Kommunikation [[@donner_was_2018]]

Verschiedene SNMP Versionen [[@donner_was_2018]]

Agenten kommunizieren mit einem oder mehreren zentralen Manager
Agent -> Software, die auf überwachten Komponenten läuft
Software kann Status und Konfiguration erfassen, Aktionen ausführen, Einstellungen vornehmen
[[@donner_was_2018]]

Manager -> kommuniziert mit Agents und nimmt deren Meldungen entgegen
Kommunikationsprotokoll ist SNMP [[@donner_was_2018]]

Ablauf Kommunikation:
Manager schickt Request an Agent -> führt diesen aus -> antwortet mit Response [[@donner_was_2018]]

Agent kann unaufgeforderte Informationen per Trap versenden -> unvorhergesehene oder kritische Ereignisse [[@donner_was_2018]]

---

Agent -> auf Netzgeräten und -diensten -> kommunizieren mit Netzwerkmanagementsystem -> tauschen Statusinformationen und Konfigurationsänderungen aus [[@jessica_scarpati_was_nodate]]

NMS ist einzige Schnittstelle für Administrator -> kann Batch-Befehle ausführen und automatische Warnmeldungen erhalten [[@jessica_scarpati_was_nodate]]

SNMP basiert auf MIB
MIB organisiert, wie Informationen über Gerätemetriken ausgetauscht werden  [[@jessica_scarpati_was_nodate]]

MIB ist formale Beschreibung von Komponenten und Statusinformationen von Geräten  [[@jessica_scarpati_was_nodate]]

MIBs können für jedes Netzwerkgerät erstellt werden  [[@jessica_scarpati_was_nodate]]

Mischung aus Pull und Push Kommunikation zwischen Netzgeräten und NMS
Agent mit MIB auf Netzgerät sammelt ständig Statusinformationen
Sendet nur auf Anfrage oder wenn überwachter Aspekt Schwellwert überschreitet -> Trap
Trap wird an Managementsystem gesendet, wenn z.B. Fehlerzustand auftritt [[@jessica_scarpati_was_nodate]]

Enthält *Inform*-Nachrichtentyp -> ermöglicht Monitoring-Tool Nachrichten von einem Gerät zu bestätigen
*Set*-Nachricht -> Änderung an Netzwerkgerät [[@jessica_scarpati_was_nodate]]

Kommunikation meist synchron -> Kommunikation wird von Manager initiert; Agent antwortet [[@jessica_scarpati_was_nodate]]

SNMP verwendet UDP Ports 161 (SNMP) und 162 (SNMPTRAP); in allen Versionen gleich [[@jessica_scarpati_was_nodate]]

SNMP ist *simple* weil Struktur des Protokolls unkompliziert ist [[@jessica_scarpati_was_nodate]]

Agent:
- läuft auf zu überwachenden Geräten
- Sammelt Daten über Systemmetriken z.B. Festplattenspeicher, Bandbreitennutzung usw.
- Manager sendet Request
- Agent schickt Response mit angeforderten Daten
- Agent kann auch proaktiv Informationen schicken (Trap) [[@jessica_scarpati_was_nodate]]

Manager:
- NMS (Netzwerkmanagementsystem)
- zentrale Konsole für Administrator
- NMS fordert Agenten auf, Infos in regelmäßigen Abständen zu schicken [[@jessica_scarpati_was_nodate]]

MIB:
- Textdatei
- listet alle Objekte auf Gerät auf, die per SNMP abgefragt oder gesteuert werden können
- Jede MIB wird Objectidentifier (OID) zugewiesen[[@jessica_scarpati_was_nodate]]

---

SNMP = Simple Network Management Protocol [[@noauthor_was_nodate-4]]

Weit verbreitetes Protokoll zum Monitoring von Netzwerkgeräten [[@noauthor_was_nodate-4]]

Auch Verwaltung und Konfiguration möglich [[@noauthor_was_nodate-4]]

Mitte 1980er entwickelt, in 1990er und Anfang 2000er zu Standard entwickelt [[@noauthor_was_nodate-4]]

Noch heute weit verbreitet, aufgrund Simplizität und hoher Bandbreite an Metriken [[@noauthor_was_nodate-4]]

Nicht Fehlerfrei, deshalb drei Versionen [[@noauthor_was_nodate-4]]

Zwei Komponenten: Agent und Manager [[@noauthor_was_nodate-4]]

Agent:
- kleine Applikation
- sammelt lokal Metriken und sendet diese an remote Standort
- kann Traps versenden
- Drei Aufgaben:
	- Get-Abfragen von Manager beantworten
	- Konfiguration/Verwaltung vom Host
	- Trap
- oft auf Netzwerkgeräten vorinstalliert
- für viele Betriebssysteme verfügbar
[[@noauthor_was_nodate-4]]

Manager:
- empfängt Metriken von Agent
- Fragt Metriken von Agent ab
- auf Network Management Station
- Zuständig für Monitoring und entsprechende Verarbeitungsaufgaben
[[@noauthor_was_nodate-4]]

Version 1 ist aus allen modernen Infrastrukturen verschwunden [[@noauthor_was_nodate-4]]

V1 hatte keine Sicherheit [[@noauthor_was_nodate-4]]

Version 2c ist am weitesten verbreitet
Wurde 1993 veröffentlicht
Version 2: Neue Befehle und parteibasiertes Sicherheitssystem -> hat sich nicht durchgesetzt
v2c: Community-basiertes Sicherheitssystem und 64 Bit-Zähler [[@noauthor_was_nodate-4]]

v2u:
- Parallel zu v2c entwickelt
- bessere Sicherheit als v1
- weniger komplex als v2
- nicht weit verbreitet
- Inspiration für v3
[[@noauthor_was_nodate-4]]

v2 ist nicht kompatibel zu v1 [[@noauthor_was_nodate-4]]

v3:
- erschien in den frühen 2000ern
- Unterstützung für Kryptographie
- Kernprotokoll hat sich nicht geändert
- Hersteller blieben bei besser getesteten und weniger rechenintensiven v2 und v2c
[[@noauthor_was_nodate-4]]

SNMP -> Komplettlösung für Monitoring [[@noauthor_was_nodate-4]]

Haupteinsatzgebiete:
- Monitoring
- Remote-Verwaltung
- Remote-Konfiguration
[[@noauthor_was_nodate-4]]

SNMP-Walk:
- Abruf aller SNMP-Daten auf Gerät
[[@noauthor_was_nodate-4]]

OID:
- Object Identifier
- Identifikationsmechanismus
- Benennt jede Art von Objekt oder Konzept
- internationaler Standard
- SNMP hat diesen übernommen
- lange Zahlenfolge, durch Punkte getrennt
- Einige Zweige allgemein, andere Hersteller/Produktspezifisch
- Jeder Hersteller kann eigene Zweige spezifizieren
[[@noauthor_was_nodate-4]]

[[grafik-OID-tree.jpeg]] [[@noauthor_was_nodate-4]]

MIB:
- Management Information Base
- übersetzt OID in Menschenlesbare Form
- Stellt Namen, Definitionen und Beschreibungen bereit
- hat Zeilen, die Informationen oder Einstellungen für Objekt darstellen
- Je komplexer Gerät, desto mehr Ziffern
- Vom Hersteller herausgegeben und gepflegt
- Für Funktion nicht unbedingt notwendig 
[[@noauthor_was_nodate-4]]

Basierend auf SNMP-Version ist ein Community-String erforderlich [[@noauthor_was_nodate-4]]

Adresse der Zielgeräte notwendig [[@noauthor_was_nodate-4]]

SNMP-Walk einfache Methode um Überblick über eins oder mehrere Geräte zu erhalten [[@noauthor_was_nodate-4]]

Agent kann allgemeine und herstellerspezifische Traps verschicken:
- allgemeine Traps:
	- übliche Ereignisse z.B. Verbindung unterbrochen
- Herstellerspezifische Traps
	- eigene, vom Gerätehersteller definierte Meldungen
 [[@noauthor_was_nodate-4]]

Manager reagiert auf Traps entsprechend Administratorrichtlinien[[@noauthor_was_nodate-4]]

Traps entsprechen Echtzeit-Benachrichtigungsystem [[@noauthor_was_nodate-4]]

Community-String:
- Passwort zur Authentifizierung zwischen Agent und Manager
- alphanumerische Zahlenfolge
- Bei v1 und v2c Zeichenfolge als Plain Text über Netzwerk gesendet
- mit v3 wurde Verschlüsselung von Community-Strings eingeführt
- Verschlüsselung muss vorkonfiguriert werden
- Belastet Agent und Manager stärker
[[@noauthor_was_nodate-4]]

SNMP ist nicht sicher und sollte nur in internen Netzwerken eingesetzt werden [[@noauthor_was_nodate-4]]

---

SNMPv1:
- kritische Sicherheitslücken und Performancelimitierungen
- Authentifizierung basiert auf einem Community-String
- IP ACLs sind notwendig
- übermittelte Daten sind nicht verschlüsselt
- Bulkabfragen sind nicht möglich
[[@noction_snmp_2022]]

SNMPv2c:
- führt 64 Bit Counter ein
- verbessert Performance im Netzwerk
- führt Bulkabfragen ein
- führt Möglichkeit für Manager-Manager-Kommunikation ein
	- Inform Request
	- Manager 1 sendet diese wiederholt an Manager 2 bis diese quittiert wird
- Community-String zur Authentifizierung
[[@noction_snmp_2022]]

SNMPv3:
- Führt Message Integrity, Verschlüsselung und Authentifizierung ein
- führt ACL mit SNMP View, Gruppen und User ein
	- noauth – nor authentication or encryption
	- auth – only authentication, no encryption
	- priv – authentication and encryption
[[@noction_snmp_2022]]