### ~~Betriebssystem-Virtualisierung mit Container

![Betriebssystem-Virtualisierung](https://www.elektronik-kompendium.de/sites/com/bilder/11010111.gif)

~~Bei der Betriebssystem-Virtualisierung läuft nur ein Betriebssystem. Darauf werden mehrere virtuelle Laufzeitumgebungen erzeugt (Jails), die für die laufenden Programme als normale Betriebssysteme wirken. Die Applikationen sehen nur die Applikationen, mit denen sie ihre virtuelle Umgebung teilen. Die Laufzeitumgebungen sind schnell erzeugt, da sie nur Abbilder des Wirtssystems sind. Allerdings können einzelne Abbilder nicht verändert werden. Nur das Grundsystem kann verändert werden und dass verändert dann auch die Abbilder.  
Beispiele sind FreeBSD Jails, Solaris Zone/Container, Linux VServer, Open VZ und Virtuozzo. [[@noauthor_virtualisierung_nodate]]

### ~~Betriebssystem-Virtualisierung mit Container (Jail)

- Solaris/OpenSolaris
- Zoning
- BSD jails
- Mac-on-Linux
- OpenVZ
- Virtuozzo
- Linux-VServer
- UML - User Mode Linux
- Linux Container (LXC)[[@noauthor_virtualisierung_nodate]]

---

## ~~Überblick

~~Linux®-[Container](https://www.redhat.com/de/topics/containers-v1) und [virtuelle Maschinen (VMs)](https://www.redhat.com/de/topics/virtualization/what-is-a-virtual-machine) sind paketierte Computing-Umgebungen, die verschiedene IT-Komponenten vereinen und vom Rest des Systems isolieren. Sie unterscheiden sich hauptsächlich in Bezug auf ihre Skalierbarkeit und Portierbarkeit. [[@noauthor_container_nodate]]

- ~~Container werden gewöhnlich in Megabyte gemessen. In einen Container werden nur die App und alle zum Ausführen erforderlichen Dateien paketiert. Häufig werden darin auch einzelne Funktionen paketiert, die bestimmte Aufgaben (sogenannte [Microservices](https://www.redhat.com/de/topics/microservices)) ausführen. Container können aufgrund ihrer geringen Größe und ihres gemeinsam genutzten Betriebssystems (OS) sehr einfach in verschiedenen Umgebungen hin- und hergeschoben werden.

- ~~VMs werden gewöhnlich in Gigabyte gemessen. Sie enthalten normalerweise ihr eigenes Betriebssystem, auf dem sie mehrere ressourcenintensive Funktionen auf einmal ausführen können. Dank der zahlreichen, ihnen zur Verfügung stehenden Ressourcen können VMs ganze Server, Betriebssysteme, Desktops, Datenbanken und [Netzwerke](https://www.redhat.com/de/topics/virtualization/what-is-nfv) abstrahieren, aufteilen, duplizieren und emulieren. [[@noauthor_container_nodate]]

~~Neben den technologischen Unterschieden steht der Vergleich von Containern mit VMs stellvertretend für den Vergleich zwischen neuen IT-Praktiken und traditionellen IT-Architekturen.  [[@noauthor_container_nodate]]

~~**Neue IT-Praktiken** ([cloudnative](https://www.redhat.com/de/topics/cloud-native-apps) Entwicklung, [CI/CD](https://www.redhat.com/de/topics/devops/what-is-ci-cd) und [DevOps](https://www.redhat.com/de/topics/devops)) sind möglich, weil die Workloads in möglichst kleine wartungsfähige Einheiten aufgeteilt werden können – normalerweise in eine einzelne Funktion oder einen Microservice. Diese kleinen Einheiten werden am besten in Containern paketiert, sodass mehrere Teams an einzelnen Teilen einer App oder eines Service arbeiten können, ohne den in anderen Containern paketierten Code zu unterbrechen oder zu gefährden. [[@noauthor_container_nodate]]

~~**Traditionelle IT-Architekturen** (monolithische und Legacy-Anwendungen) verwenden einen einzigen großen Dateityp für alle Aspekte einer Workload. Dieser Dateityp kann nicht aufgeteilt werden und muss daher als ganze Einheit in einer größeren Umgebung, häufig einer VM, paketiert werden. Früher war es üblich, eine komplette App innerhalb einer VM zu erstellen und auszuführen. Der gesamte Code und die Abhängigkeiten führten jedoch zu übergroßen VMs, und beim Durchführen von Updates traten Kaskadierungsfehler und Ausfallzeiten auf. [[@noauthor_container_nodate]]

## Welches Konzept ist für mich geeignet?

~~Das kommt darauf an: Benötigen Sie eine kleine, verschiebbare Instanz (Container) oder eine semipermanente Zuweisung von benutzerdefinierten IT-Ressourcen? [[@noauthor_container_nodate]]

~~Aufgrund ihrer geringen Größe sind Container problemlos in Bare-Metal-Systemen sowie Public, Private, Hybrid und Multi-Cloud-Umgebungen verschiebbar. Sie sind auch die ideale Umgebung für die cloudnativen Apps von heute, die aus mehreren Microservices bestehen und mit denen die Entwicklung und [automatisierte](https://www.redhat.com/de/topics/automation)[Verwaltung](https://www.redhat.com/de/topics/management) von [Public](https://www.redhat.com/de/topics/cloud-computing/what-is-public-cloud)[,](https://www.redhat.com/de/topics/cloud-computing/what-is-private-cloud) Private[, Hybrid](https://www.redhat.com/de/topics/cloud-computing/what-is-hybrid-cloud) und [Multi-Cloud](https://www.redhat.com/de/topics/cloud-computing/what-is-multicloud)-Umgebungen überhaupt erst möglich wird. Cloudnative Apps tragen dazu bei, die Erstellung neuer Apps, die Optimierung bestehender Apps und die Verknüpfung aller Apps zu beschleunigen. Dabei ist jedoch erforderlich, dass die Container mit dem zugrunde liegenden Betriebssystem kompatibel sind. Im Vergleich zu VMs eignen sich Container besser, um:

- ~~cloudnative Apps zu entwickeln
- ~~Microservices zu paketieren
- ~~DevOps- oder CI/CD-Praktiken einzuführen
- ~~skalierbare IT-Projekte in einer uneinheitlichen IT-Umgebung zu verschieben, die unter einem gemeinsamen Betriebssystem läuft [[@noauthor_container_nodate]]

~~VMs können weit mehr Vorgänge ausführen als ein einzelner Container. Aus diesem Grund werden noch immer monolithische Workloads paketiert. Diese erweiterte Funktionalität macht VMs jedoch aufgrund ihrer Abhängigkeit vom Betriebssystem, der Anwendung und den Libraries weitaus schlechter portierbar. Im Vergleich zu Containern eignen sich VMs besser, um:

- ~~traditionelle, Legacy- und monolithische Workloads unterzubringen
- ~~riskante Entwicklungszyklen zu isolieren
- ~~[Infrastrukturressourcen](https://www.redhat.com/de/topics/cloud-computing/what-is-it-infrastructure) (wie Netzwerke, Server und [Daten](https://www.redhat.com/de/topics/big-data)) zu provisionieren
- ~~ein Betriebssystem unter einem anderen Betriebssystem (z. B. Unix unter [Linux](https://www.redhat.com/de/topics/linux)) auszuführen [[@noauthor_container_nodate]]

## Wie funktioniert das?

[![virtualization vs containers](https://www.redhat.com/rhdc/managed-files/styles/wysiwyg_full_width/private/virtualization-vs-containers_transparent.png?itok=kpBl0OG5 "virtualization vs containers")](https://www.redhat.com/rhdc/managed-files/virtualization-vs-containers_transparent.png)

### Container

~~Container enthalten einen Microservice oder eine App und alles, was zu deren Ausführung erforderlich ist. Der gesamte Inhalt eines Containers wird in einem Image abgebildet. Dies ist eine codebasierte Datei, die alle Libraries und Abhängigkeiten enthält. Man kann sich diese Dateien als Installation einer Linux-Distribution vorstellen, weil das Image alle RPM-Pakete und Konfigurationsdateien enthält. Da Container sehr klein sind, werden normalerweise Hunderte von Containern lose miteinander gekoppelt. Aus diesem Grund werden [Container-Orchestrierungsplattformen](https://www.redhat.com/de/topics/containers/what-is-container-orchestration) (wie [Red Hat OpenShift](https://www.redhat.com/de/technologies/cloud-computing/openshift) und [Kubernetes](https://www.redhat.com/de/topics/containers/what-is-kubernetes)) verwendet, um sie bereitzustellen und zu verwalten. [[@noauthor_container_nodate]]

---

#### _Virtualisierung auf Betriebssystemebene_

~~Virtualisierungskonzepte auf Betriebssystemebene greifen auf **native Kernel-Funktionen unixoider Betriebssysteme** zurück, die es ermöglichen, mehrere voneinander isolierte User-Space-Instanzen parallel auszuführen. Anders als bei der Hardware-Virtualisierung wird somit kein komplettes Gastsystem inklusive Kernel nachgebildet. Stattdessen teilen sich auf Betriebssystemebene virtualisierte Anwendungen den Kernel des Wirtssystems.
[[@noauthor_konzepte_2021]]

 Hinweis

~~Moderne Betriebssysteme unterscheiden aus Sicherheitsgründen zwischen zwei virtuellen Speicherbereichen: _Kernel-Space_ und _User-Space_. Während Prozesse, die dem Betrieb des Kernels und anderer Kernkomponenten dienen, im Kernel-Space ausgeführt werden, steht der User-Space Nutzeranwendungen zur Verfügung. Auf unixoiden Betriebssystemen ist es möglich, mehrere virtuelle User-Space-Instanzen parallel auszuführen. Dieses Feature ist die Grundlage der Virtualisierung auf Betriebssystemebene.
[[@noauthor_konzepte_2021]]

~~Jede **User-Space-Instanz** stellt eine in sich abgeschlossene virtuelle [Laufzeitumgebung](https://www.ionos.de/digitalguide/websites/web-entwicklung/was-ist-eine-laufzeitumgebung/ "Was ist eine Laufzeitumgebung?") dar, die je nach verwendeter Technologie _Container_, _Partition_, _Virtualization_ _Engine_ (kurz: VE) oder _Jail_ genannt wird. Ein Revival feierte die betriebssystembasierte Virtualisierung mit **Container-Plattformen** wie [Docker](https://www.ionos.de/digitalguide/server/knowhow/docker-tools-das-oekosystem-der-container-plattform/ "Docker-Tools | Das Ökosystem der Container-Plattform"). Mittlerweise stehen Anwendern mit rtk, OpenVZ/Virtuozzo und runC ausgereifte Alternativen zum Marktführer zur Verfügung.
[[@noauthor_konzepte_2021]]

~~Die Virtualisierung von User-Space-Instanzen erfolgt mittels nativer **Chroot-Mechanismen**, die alle unixoiden Betriebssysteme bereitstellen. Bei _Chroot_ (kurz für „change root“) handelt es sich um einen Systemaufruf, der es erlaubt, das Root-Verzeichnis eines laufenden Prozesses zu ändern. Prozesse, die in ein virtuelles Root-Verzeichnis ausgelagert werden, können bei korrekter Implementierung nur noch auf Dateien innerhalb dieses Verzeichnisses zugreifen. Chroot allein kapselt Prozesse jedoch nur ungenügend. Der Systemaufruf stellt zwar grundlegende Virtualisierungsfunktionen zur Verfügung, war jedoch nie als Konzept zur Absicherung von Prozessen gedacht. Container-Technologien kombinieren Chroot daher mit anderen nativen Kernel-Funktionen wie **Cgroups und Namespaces**, um Prozessen eine isolierte Laufzeitumgebung mit limitiertem Zugriff auf Hardware-Ressourcen zur Verfügung zu stellen. Man spricht von containerisierten Prozessen.
[[@noauthor_konzepte_2021]]

- ~~**Cgroups:** Bei Cgroups handelt es sich um Kontrollgruppen für das Ressourcen-Management, die es ermöglichen, die Zugriffe von Prozessen auf Hardware-Ressourcen zu limitieren.  
     
- ~~**Namespaces:** Bei Namespaces handelt es sich um Namensräume für die System- und Prozess-Identifikation sowie für die Interprozess-Kommunikationen und für Netzwerkressourcen. Mit Namespaces lassen sich ein Prozess und dessen Kindprozesse auf einen gewünschten Ausschnitt des zugrundeliegenden Systems beschränken.

~~Ein **Software-Container** beinhaltet eine Anwendung inklusive aller Abhängigkeiten wie Bibliotheken, Hilfsprogramme oder Konfigurationsdateien. Containerisiert lassen sich Anwendungen ohne weitere Anpassungen und von einem System auf ein anderes übertragen. Seine Stärken spielt der Container-Ansatz daher bei der Bereitstellung von Anwendungen im Netzwerk (_Deployment_) aus.
[[@noauthor_konzepte_2021]]

~~Kommen Container im Rahmen von **[Microservice-Architekturen](https://www.ionos.de/digitalguide/websites/web-entwicklung/microservice-architecture-so-funktionieren-microservices/ "Microservice-Architecture | So funktionieren Microservices")** zum Einsatz, profitieren Anwender zudem von einer hohen Skalierbarkeit. Bei Microservices handelt es sich um einen Entwicklungsansatz zur **Modularisierung von Software**. In Microservice-Architekturen werden komplexe Anwendungen durch das Zusammenspiel unabhängiger Prozesse realisiert – beispielsweise in einem eigenen Container. Man spricht von einer **Multi-Container-App**. Ein solcher Software-Aufbau hat diverse Vorteile: Microservices erleichtern das Deployment von Anwendungen in Server-Clustern, da containerisierte Prozesse bei Bedarf auf demselben System ausgeführt oder über verschiedene Systeme hinweg verteilt werden können. Zudem kann jeder **Microservice einzeln skaliert** werden. Anwender starten dazu einfach eine weitere Instanz des jeweiligen Microservices in einem neuen Container.
[[@noauthor_konzepte_2021]]


~~Die Verwaltung von Microservice-Architekturen im Cluster erfolgt über zentrale **Cluster-Manager und Orchestrierungswerkzeuge**. Finden Sie in unserem Artikel eine Auswahl der beliebtesten [Docker-Tools](https://www.ionos.de/digitalguide/server/knowhow/docker-tools-das-oekosystem-der-container-plattform/ "Docker-Tools | Das Ökosystem der Container-Plattform").

~~Im Vergleich zur Hardware-Virtualisierung zeichnet sich die Container-Technologie durch einen **minimalen Virtualisierungsschwund** aus. Der Overhead der Hypervisor-Software entfällt. Während für jede VM ein eigenes Betriebssystem virtualisiert werden muss, ermöglicht es die Container-Technologie, mehrere tausend Microservices in isolierten Laufzeitumgebungen auf ein und demselben Betriebssystem auszuführen.
[[@noauthor_konzepte_2021]]


---

## Wie unterscheidet sich die Servervirtualisierung von der Containerisierung?

~~Die Containerisierung ist eine Möglichkeit, Anwendungscode so zu implementieren, dass er in jeder physischen oder virtuellen Umgebung ohne Änderungen ausgeführt werden kann. Entwickler bündeln den Anwendungscode mit zugehörigen Bibliotheken, Konfigurationsdateien und anderen Abhängigkeiten, die der Code zur Ausführung benötigt. Dieses einzelne Softwarepaket, ein so genannter [Container](https://aws.amazon.com/getting-started/deep-dive-containers/), kann unabhängig auf jeder Plattform laufen. Die Containerisierung ist eine Art der Anwendungsvirtualisierung.
[[@noauthor_was_nodate-6]]

~~Sie können sich die Servervirtualisierung wie den Bau einer Straße vorstellen, die zwei Orte miteinander verbindet. Sie müssen eine komplette virtuelle Umgebung neu erstellen und dann Ihre Anwendung darauf ausführen. Im Vergleich dazu ist die Containerisierung wie der Bau eines Hubschraubers, der an jeden dieser Orte fliegen kann. Ihre Anwendung befindet sich in einem Container und kann in allen Arten von physischen oder virtuellen Umgebungen ausgeführt werden.
[[@noauthor_was_nodate-6]]


---

# Stichpunkte


![Betriebssystem-Virtualisierung](https://www.elektronik-kompendium.de/sites/com/bilder/11010111.gif)
[[@noauthor_virtualisierung_nodate]]

- Es läuft nur ein Betriebssystem.
- Mehrere virtuelle Laufzeitumgebungen (Jails) werden erzeugt.
- Die Jails wirken für Programme wie normale Betriebssysteme.
- Applikationen sehen nur die in ihrer virtuellen Umgebung geteilten Applikationen.
- Die Laufzeitumgebungen sind schnell erstellt, da sie Abbilder des Wirtssystems sind.
- Einzelne Abbilder können nicht verändert werden; Änderungen erfolgen im Grundsystem und wirken sich auf alle Abbilder aus.
- Beispiele: FreeBSD Jails, Solaris Zone/Container, Linux VServer, Open VZ und Virtuozzo.
[[@noauthor_virtualisierung_nodate]]

---

Linux-Container und VMs sind paketierte Computing-Umgebungen
Vereinen verschiedene IT-Komponenten
Sind vom Rest des Systems isoliert
Unterscheiden sich in Bezug auf Skalierbarkeit und Portierbarkeit
[[@noauthor_container_nodate]]

Container sind meist nur wenige MB groß
Alle notwendigen Bibliotheken und Dateien zum Ausführen einer Applikation sind enthalten -> und nur diese!
Grundlage für Microservices -> Enthalten nur einzelne Funktionen, die in einer größeren Architektur eingesetzt werden
Aufgrund ihrer geringen Größe einfach zwischen Hosts zu verschieben.
[[@noauthor_container_nodate]]

VMs wiegen mehrere Gigabyte
Enthalten eigenes Betriebssystem und Kernel
VMs können u.a. ganze Server, Betriebssysteme, Netzwerke enthalten
[[@noauthor_container_nodate]]

Container ermöglichen neue IT-Praktiken:
	- CI/CD bzw. DevOps
	- Workloads werden in möglichst kleine wartungsfähige Einheiten aufgeteilt
	- einzelne Funktion bzw. Mikroservice
	- Diese werden in Container paketiert
	- Mehrere Teams können an Service arbeiten, ohne bereits vorhandene Funktionalität zu gefährden
	- [[@noauthor_container_nodate]]

- Container sind klein
- Deploybar auf Bare-Metal-Systemem und Cloud-Umgebungen
- Eignen sich für:
	- cloudnative Apps
	- Microservices
	- DepOps bzw CI/CD Praktiken
[[@noauthor_container_nodate]]

- VMs können mehr Vorgänge ausführen als Container
- Monolithische Workloads werden deshalb in diesen Packetiert
- schlechter portierbar
[[@noauthor_container_nodate]]

[![virtualization vs containers](https://www.redhat.com/rhdc/managed-files/styles/wysiwyg_full_width/private/virtualization-vs-containers_transparent.png?itok=kpBl0OG5 "virtualization vs containers")](https://www.redhat.com/rhdc/managed-files/virtualization-vs-containers_transparent.png)
[[@noauthor_container_nodate]]

Container:
- enthalten Microserver oder App
- mit allen notwendigen Bibliotheken und Dateien
- Inhalt des Containers wird als Image abgebildet
	- Codebasierte Datei, die alle Abhängigkeiten enthält
- Microservices können aus hunderten von Containern bestehen -> Deshalb werden Orchestrierungsplattformen wie OpenShift oder Kubernetes verwendet
[[@noauthor_container_nodate]]

---

Virtualisierung auf Betriebssystemebene:
- nutzt native Kernel-Funktionen unixoider Betriebssysteme zurück
- Ermöglichen es, voneinander isolierte User-Space-Instanzen parallel auszuführen
- Kein komplettes Gastsystem inklusive Kernel
- Container nutzen Kernel des Hostsystems
[[@noauthor_konzepte_2021]]

Moderne Betriebssysteme trennen zwischen User-Space und Kernel-Space
Kernel-Space:
- Treiber
- Betrieb des Kernels
- andere Kernkomponenten
[[@noauthor_konzepte_2021]]

User-Space:
- enthält Code des Anwenders
[[@noauthor_konzepte_2021]]

Userspace-Instanz -> in sich abgeschlossene Laufzeitumgebung -> z.B. Docker, rtk, runC
[[@noauthor_konzepte_2021]]

Virtualisierung von Userspace-Instanzen erfolgt mittels nativer Chroot-Mechanismen
- chroot (change root):
	- Systemcall, der Root-Verzeichnis eines laufenden Prozesses ändert
	- Prozess kann dann nur noch auf Daten innerhalb dieses Verzeichnis zugreifen -> korrekte Implementierung vorausgesetzt
	- chroot Kapselung ist nur ungenügend
	- War nie als Konzept zur Absicherung von Prozessen gedacht
	- Contrainer-Technologien kombinieren deshalb u.a. Cgroups und Namespaces um Laufzeitumgebungen mit limitierten Hardwarezugriff zu erzeugen
	- Cgroups:
		- Kerneltechnologie
		- Kontrollgruppe für Ressourcen Management
		- Erlaubt Hardwarezugriff für Prozesse zu beschränken
	- Namespaces:
		- Namensraum für System und Prozessidentifikation, Interprozesskommunikation und für Netzwerkressourcen
		- Prozesse und Kindprozesse lassen sich auf gewünschten Ausschnitt des Systems begrenzen
[[@noauthor_konzepte_2021]]

Software-Container:
- beinhaltet Anwendung sowie alle Abhängigkeiten
- Abhängigkeiten -> Bibliotheken, Hilfsprogramme oder Configs
- Containerisierte Applikationen lassen sich leicht auf mehrere Systeme verteilen
- Einfache Skalierung möglich
- Grundlagen für Microservices
[[@noauthor_konzepte_2021]]

Verwaltung läuft über Orchestrierungstools wie Kubernetes
[[@noauthor_konzepte_2021]]

Minimaler Virtualisierungsoverhead, da kein eigener Kernel und kein eigenständiges OS
[[@noauthor_konzepte_2021]]

